@@ -36,12 +36,46 @@ class WialonUnit(WialonBase):
         )
         return int(response.get("item", {}).get("id")) if response.get("item") else None
 
+    def populate(self) -> None:
+        super().populate()
+        response = self.session.wialon_api.core_search_item(
+            **{
+                "id": self.id,
+                "flags": sum(
+                    [flags.DATAFLAG_UNIT_ADVANCED_PROPERTIES, flags.DATAFLAG_UNIT_IMAGE]
+                ),
+            }
+        ).get("item", {})
+        self._imei_number = response.get("uid")
+        self._active = response.get("act", False)
+        self._image_uri = response.get("uri")
+
+    def get_position(self) -> dict:
+        return self.session.wialon_api.core_search_item(
+            **{"id": self.id, "flags": flags.DATAFLAG_UNIT_POSITION}
+        )
+
     @property
     def available_commands(self) -> dict:
         return self.session.wialon_api.core_get_hw_cmds(
             **{"deviceTypeId": 0, "unitId": self.id}
         )
 
+    @property
+    def image_uri(self) -> str:
+        return self._image_uri
+
+    @property
+    def imei_number(self) -> int | None:
+        if self._imei_number:
+            return int(self._imei_number)
+
+    @property
+    def active(self) -> bool:
+        if self._active:
+            return bool(self._active)
+        return False
+
     def execute_command(
         self,
         name: str,
@@ -165,6 +199,7 @@ class WialonUnit(WialonBase):
         return list(dict.fromkeys(phone_numbers))  # Removes duplicate phone numbers
 
     def clean_phone_numbers(self, phones: list[str]) -> list[str]:
+        """Takes a list of phone numbers and returns a list of clean phone numbers."""
         cleaned_phones = []
         for num in phones:
             if "," in num:
